@@ -43,6 +43,7 @@
 
 #include <qabstracttextdocumentlayout.h>
 #include <qdebug.h>
+#include <qloggingcategory.h>
 #include <qpainter.h>
 #include <qscopedvaluerollback.h>
 #include <qtextcursor.h>
@@ -53,6 +54,8 @@
 
 QT_BEGIN_NAMESPACE
 
+Q_LOGGING_CATEGORY(lcSvgDraw, "qt.svg.draw")
+
 #define QT_SVG_DRAW_SHAPE(command)                          \
     qreal oldOpacity = p->opacity();                        \
     QBrush oldBrush = p->brush();                           \
@@ -469,15 +472,27 @@ void QSvgUse::draw(QPainter *p, QSvgExtraStates &states)
     if (Q_UNLIKELY(!m_link || isDescendantOf(m_link) || m_recursing))
         return;
 
+    Q_ASSERT(states.nestedUseCount == 0 || states.nestedUseLevel > 0);
+    if (states.nestedUseLevel > 3 && states.nestedUseCount > (256 + states.nestedUseLevel * 2)) {
+        qCDebug(lcSvgDraw, "Too many nested use nodes at #%s!", qPrintable(m_linkId));
+        return;
+    }
+
     applyStyle(p, states);
 
     if (!m_start.isNull()) {
         p->translate(m_start);
     }
+    if (states.nestedUseLevel > 0)
+        ++states.nestedUseCount;
     {
-        QScopedValueRollback<bool> guard(m_recursing, true);
+        QScopedValueRollback<int> useLevelGuard(states.nestedUseLevel, states.nestedUseLevel + 1);
+        QScopedValueRollback<bool> recursingGuard(m_recursing, true);
         m_link->draw(p, states);
     }
+    if (states.nestedUseLevel == 0)
+        states.nestedUseCount = 0;
+
     if (!m_start.isNull()) {
         p->translate(-m_start);
     }
